@@ -1,7 +1,7 @@
 see.chicdf.tck<-function () 
 {
 
-  old.par <- par(no.readonly = TRUE)
+ # old.par <- par(no.readonly = TRUE)
   
     if (!exists("slider.env")) 
     slider.env <- NULL; suppressWarnings(rm(slider.env)); slider.env <<- new.env()# Dummy to trick R CMD check 
@@ -51,7 +51,7 @@ see.chicdf.tck<-function ()
         side = "left")
     tkpack(tkbutton(m, text = "Exit", command = function() tkdestroy(m)), 
         side = "right")
-    on.exit(par(old.par))
+#    on.exit(par(old.par))
         }
 
 
